@@ -1,7 +1,7 @@
-__version__ = '0.8.1'
+__version__ = '0.8.2'
 __author__ = 'Eduardo S. Klein'
 __email__ = 'duduklein@gmail.com'
-__url__ = 'http://bitbucket.org/eduardoklein/django-setup/'
+__url__ = 'http://bitbucket.org/duduklein/django-setup/'
 
 import os
 
