@@ -12,5 +12,5 @@ def get_test_runner(INSTALLED_APPS, DATABASES, USE_CELERY=False):
     SKIP_SOUTH_TESTS = True # To disable South's own unit tests
     NOSE_ARGS = ['--match=^test', '--with-coverage',
                  '--with-yanc', '--cover-erase',
-                 '--logging-level=INFO'] 
+                 '--logging-level=INFO','--ipdb','--ipdb-failures']
     return INSTALLED_APPS, DATABASES, TEST_RUNNER, SOUTH_TESTS_MIGRATE, SKIP_SOUTH_TESTS, NOSE_ARGS
